==> apache-camel-3.20.1-src.zip: apache-camel-3.20.1/components/camel-sjms/src/test/java/org/apache/camel/component/sjms/SimpleJmsComponentTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.sjms;

import org.apache.activemq.ActiveMQConnectionFactory;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertNotNull;

public class SimpleJmsComponentTest extends CamelTestSupport {

    @Test
    public void testHelloWorld() {
        SjmsComponent component = context.getComponent("sjms", SjmsComponent.class);
        assertNotNull(component);
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            public void configure() {
                ActiveMQConnectionFactory connectionFactory
                        = new ActiveMQConnectionFactory("vm://broker?broker.persistent=false&broker.useJmx=false");
                SjmsComponent component = new SjmsComponent();
                component.setConnectionFactory(connectionFactory);
                getContext().addComponent("sjms", component);
            }
        };
    }
}

==> apache-camel-4.16.0-src.zip: apache-camel-4.16.0/components/camel-sjms/src/test/java/org/apache/camel/component/sjms/SimpleJmsComponentTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.camel.component.sjms;

import org.apache.activemq.artemis.jms.client.ActiveMQConnectionFactory;
import org.apache.camel.builder.RouteBuilder;
import org.apache.camel.test.junit5.CamelTestSupport;
import org.junit.jupiter.api.Test;

import static org.junit.jupiter.api.Assertions.assertNotNull;

public class SimpleJmsComponentTest extends CamelTestSupport {

    @Test
    public void testHelloWorld() {
        SjmsComponent component = context.getComponent("sjms", SjmsComponent.class);
        assertNotNull(component);
    }

    @Override
    protected RouteBuilder createRouteBuilder() {
        return new RouteBuilder() {
            public void configure() {
                ActiveMQConnectionFactory connectionFactory
                        = new ActiveMQConnectionFactory("vm://broker?broker.persistent=false&broker.useJmx=false");
                SjmsComponent component = new SjmsComponent();
                component.setConnectionFactory(connectionFactory);
                getContext().addComponent("sjms", component);
            }
        };
    }
}
